@@ -696,75 +696,6 @@ SEXP catnetNodeLoglik(SEXP cnet, SEXP rNode, SEXP rSamples, SEXP rPerturbations)
 
 }
 
-SEXP catnetNodeLoglikError(SEXP cnet, SEXP rNode, SEXP rSamples, SEXP rPerturbations) {
-
-	int *pSamples;
-	int numsamples, numnodes, j, nnode, nerrors;
-	double *floglik, *pvec;
-	SEXP dim, rvec = R_NilValue;
-
-	if(!isMatrix(rSamples))
-		error("Data is not a matrix");
-	if(!isNull(rPerturbations) && !isMatrix(rPerturbations))
-		error("Perturbations is not a vector");
-	if(!isInteger(AS_INTEGER(rNode)))
-		error("Node should be an integer");
-
-	////////////////////////////////////////
-	// Danger Ahead
-	// We don's check that sample nodes actually correspond to the cnet's nodes
-	// Missmatch of categories possible
-
-	PROTECT(cnet);
-	RCatnet *rnet = new RCatnet(cnet);
-	UNPROTECT(1);
-
-	PROTECT(rNode = AS_INTEGER(rNode));
-	nnode = INTEGER_POINTER(rNode)[0];
-	UNPROTECT(1);
-
-	PROTECT(rSamples = AS_INTEGER(rSamples));
-	pSamples = INTEGER(rSamples);
-
-	dim = GET_DIM(rSamples);
-	numnodes = INTEGER(dim)[0];
-	numsamples = INTEGER(dim)[1];
-
-	// pSamples are assumed positive indices
-	for(j = 0; j < numnodes*numsamples; j++) {
-		if(R_IsNA(pSamples[j]) || pSamples[j] < 1)
-			pSamples[j] = CATNET_NAN;
-		else
-			pSamples[j]--;
-	}
-	nnode--;
-
-	//int *pPerturbations = 0;
-	//if(!isNull(rPerturbations)) {
-	//	PROTECT(rPerturbations = AS_INTEGER(rPerturbations));
-	//	pPerturbations = INTEGER(rPerturbations);
-	//	UNPROTECT(1);
-	//}
-
-	nerrors = 0;
-	floglik = rnet->findNodeSampleProbError(nnode, pSamples, numsamples, nerrors);
-
-	UNPROTECT(1);
-
-	delete rnet;
-
-	if(floglik) {
-		PROTECT(rvec = NEW_NUMERIC(nerrors));
-		pvec = NUMERIC_POINTER(rvec);
-		for(j = 0; j < nerrors; j++)
-			pvec[j] =  floglik[j];
-		UNPROTECT(1);
-	}
-
-	return rvec;
-
-}
-
 SEXP catnetSamples(SEXP cnet, SEXP rNumSamples, SEXP rPerturbations, SEXP rNaRate) {
 
 	SEXP rsamples = R_NilValue;
